summaryrefslogtreecommitdiff
path: root/keyboards/dz60/keymaps/bingocaller/keymap.c
diff options
context:
space:
mode:
Diffstat (limited to 'keyboards/dz60/keymaps/bingocaller/keymap.c')
-rw-r--r--keyboards/dz60/keymaps/bingocaller/keymap.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/keyboards/dz60/keymaps/bingocaller/keymap.c b/keyboards/dz60/keymaps/bingocaller/keymap.c
index c19f673f76..787665af78 100644
--- a/keyboards/dz60/keymaps/bingocaller/keymap.c
+++ b/keyboards/dz60/keymaps/bingocaller/keymap.c
@@ -73,12 +73,12 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* F1-12
* Del on backspace
* RGB (underglow) controls
* RESET firmware on backslash
* Screen brightness: Z (decrease), X (increase)
*/
[_FN] = LAYOUT(
_______, KC_F1, KC_F2, KC_F3, KC_F4, KC_F5, KC_F6, KC_F7, KC_F8, KC_F9, KC_F10, KC_F11, KC_F12, _______, KC_DEL,
- _______, RGB_TOG, RGB_MOD, RGB_HUI, RGB_HUD, RGB_SAI, RGB_SAD, RGB_VAI, RGB_VAD, _______, _______, _______, _______, RESET,
+ _______, RGB_TOG, RGB_MOD, RGB_HUI, RGB_HUD, RGB_SAI, RGB_SAD, RGB_VAI, RGB_VAD, _______, _______, _______, _______, QK_BOOT,
_______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
_______, _______, KC_BRMD, KC_BRMU, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______,
_______, _______, _______, _______, _______, _______, _______, _______, _______, _______, _______),
@@ -73,12 +73,12 @@ const uint16_t PROGMEM keymaps[][MATRIX_ROWS][MATRIX_COLS] = {
* Del on backspace
* RGB (underglow) controls
- * RESET firmware on backslash
+ * QK_BOOT firmware on backslash
* Screen brightness: Z (decrease), X (increase)
*/